@@ -56,7 +56,7 @@ extern int SPVM_yydebug;
     REQUIRE = 266,
     ALIAS = 267,
     ALLOW = 268,
-    CURRENT_CLASS = 269,
+    OUTMOST_CLASS = 269,
     MUTABLE = 270,
     ATTRIBUTE = 271,
     MAKE_READ_ONLY = 272,
@@ -110,7 +110,7 @@ extern int SPVM_yydebug;
     WARN = 320,
     PRINT = 321,
     SAY = 322,
-    CURRENT_CLASS_NAME = 323,
+    OUTMOST_CLASS_NAME = 323,
     UNWEAKEN = 324,
     ASSIGN = 325,
     SPECIAL_ASSIGN = 326,
